From: Takaaki Tateishi Date: 2002-12-02T18:39:17+09:00 Subject: [ruby-dev:18982] Re: st_foreach() 立石です. At Mon, 2 Dec 2002 13:31:49 +0900, > こんなのを思い付きましたが、修正個所が多くなりそうなので実際に > は試してません。 > > #define ST_FOREACH_BEGIN(table) do { \ rb_mark_tbl()についてだけこのマクロを使ってtest.rbを走らせた ところst_foreach_cont()より,良い結果がでることが多いです. ただ,以下のような程度でほんとにわずかな差です. st_foreach_cont()の場合 real 0m3.231s user 0m2.930s sys 0m0.180s ST_FOREACH_BEGINの場合 real 0m3.225s user 0m2.980s sys 0m0.110s -- Takaaki Tateishi